@@ -5,10 +5,12 @@ Constants for default values on the TFC API endpoints
 from enum import Enum
 import logging
 
+
 # Default Config Items
 TFC_SAAS_HOSTNAME = "app.terraform.io"
 TFC_SAAS_URL = "https://app.terraform.io"
-API_LOG_LEVEL = logging.CRITICAL
+TERRASNEK_LOG_LEVEL = logging.CRITICAL
+TERRASNEK_VERSION = "0.1.10"
 MAX_PAGE_SIZE = 100
 
 # Common TFC API HTTP Codes
@@ -16,6 +18,7 @@ HTTP_OK = 200
 HTTP_CREATED = 201
 HTTP_ACCEPTED = 202
 HTTP_NO_CONTENT = 204
+HTTP_MOVED_PERMANENTLY = 301
 HTTP_MOVED_TEMPORARILY = 302
 HTTP_NOT_MODIFIED = 304
 HTTP_TEMPORARY_REDIRECT = 307
@@ -36,6 +39,8 @@ class Entitlements(Enum):
     Enumeration of all the possible Terraform Cloud Entitlements, to be used
     on each endpoint to indicate the required entitlements to use that piece
     of the Terraform Cloud API.
+
+    [Entitlements Docs](https://www.terraform.io/docs/cloud/api/index.html)
     """
 
     AGENTS = "AGENTS"
@@ -45,6 +50,7 @@ class Entitlements(Enum):
     OPERATIONS = "OPERATIONS"
     PRIVATE_MODULE_REGISTRY = "PRIVATE_MODULE_REGISTRY"
     PRIVATE_NETWORKING = "PRIVATE_NETWORKING"
+    RUN_TASKS = "RUN_TASKS"
     SELF_SERVE_BILLING = "SELF_SERVE_BILLING"
     SENTINEL = "SENTINEL"
     STATE_STORAGE = "STATE_STORAGE"
@@ -53,3 +59,4 @@ class Entitlements(Enum):
     USER_LIMIT = "USER_LIMIT"
     USAGE_REPORTING = "USAGE_REPORTING"
     VCS_INTEGRATIONS = "VCS_INTEGRATIONS"
+    VIEWABLE_BILLING = "VIEWABLE_BILLING"
