@@ -1,14 +1,18 @@
+# pylint: disable=too-many-instance-attributes
+
 """
 Module for container class of all TFC endpoints and high level exceptions around
 API access.
 """
 
+from urllib.parse import urlparse
 import json
 import logging
 import requests
 import urllib3
 
-from ._constants import TFC_SAAS_URL, TFC_SAAS_HOSTNAME, HTTP_OK, API_LOG_LEVEL
+from ._constants import \
+    TFC_SAAS_URL, TFC_SAAS_HOSTNAME, HTTP_OK, TERRASNEK_LOG_LEVEL, TERRASNEK_VERSION
 from .exceptions import TFCHTTPNotFound
 
 from .account import TFCAccount
@@ -23,6 +27,7 @@ from .agents import TFCAgents
 from .agent_tokens import TFCAgentTokens
 from .applies import TFCApplies
 from .audit_trails import TFCAuditTrails
+from .comments import TFCComments
 from .config_versions import TFCConfigVersions
 from .cost_estimates import TFCCostEstimates
 from .feature_sets import TFCFeatureSets
@@ -32,6 +37,7 @@ from .oauth_clients import TFCOAuthClients
 from .oauth_tokens import TFCOAuthTokens
 from .orgs import TFCOrgs
 from .org_memberships import TFCOrgMemberships
+from .org_tags import TFCOrgTags
 from .org_tokens import TFCOrgTokens
 from .plans import TFCPlans
 from .plan_exports import TFCPlanExports
@@ -41,6 +47,9 @@ from .policy_sets import TFCPolicySets
 from .policy_set_params import TFCPolicySetParams
 from .notification_configs import TFCNotificationConfigurations
 from .registry_modules import TFCRegistryModules
+from .registry_providers import TFCRegistryProviders
+from .run_tasks import TFCRunTasks
+from .run_tasks_integration import TFCRunTasksIntegration
 from .run_triggers import TFCRunTriggers
 from .runs import TFCRuns
 from .state_versions import TFCStateVersions
@@ -54,7 +63,10 @@ from .team_tokens import TFCTeamTokens
 from .users import TFCUsers
 from .user_tokens import TFCUserTokens
 from .vars import TFCVars
+from .var_sets import TFCVarSets
+from .vcs_events import TFCVCSEvents
 from .workspace_vars import TFCWorkspaceVars
+from .workspace_resources import TFCWorkspaceResources
 from .workspaces import TFCWorkspaces
 
 # Suppress insecure TLS warnings
@@ -73,6 +85,7 @@ class TFC():
     # This dict specifies which class should be used for each attribute of this API class,
     # which simplifies the initialization of each endpoint since they share the same initialization
     # values.
+
     _class_for_attr_dict = {
         "org-not-required": {
             "admin_orgs": TFCAdminOrgs,
@@ -91,6 +104,7 @@ class TFC():
             "applies": TFCApplies,
             "agents": TFCAgents,
             "agent_tokens": TFCAgentTokens,
+            "comments": TFCComments,
             "config_versions": TFCConfigVersions,
             "cost_estimates": TFCCostEstimates,
             "feature_sets": TFCFeatureSets,
@@ -98,6 +112,7 @@ class TFC():
             "oauth_clients": TFCOAuthClients,
             "oauth_tokens": TFCOAuthTokens,
             "org_memberships": TFCOrgMemberships,
+            "org_tags": TFCOrgTags,
             "org_tokens": TFCOrgTokens,
             "plans": TFCPlans,
             "plan_exports": TFCPlanExports,
@@ -107,6 +122,9 @@ class TFC():
             "policy_set_params": TFCPolicySetParams,
             "notification_configs": TFCNotificationConfigurations,
             "registry_modules": TFCRegistryModules,
+            "registry_providers": TFCRegistryProviders,
+            "run_tasks": TFCRunTasks,
+            "run_tasks_integration": TFCRunTasksIntegration,
             "run_triggers": TFCRunTriggers,
             "runs": TFCRuns,
             "ssh_keys": TFCSSHKeys,
@@ -120,12 +138,15 @@ class TFC():
             "users": TFCUsers,
             "user_tokens": TFCUserTokens,
             "vars": TFCVars,
+            "var_sets": TFCVarSets,
+            "vcs_events": TFCVCSEvents,
             "workspace_vars": TFCWorkspaceVars,
+            "workspace_resources": TFCWorkspaceResources,
             "workspaces": TFCWorkspaces
         }
     }
 
-    def __init__(self, api_token, url=TFC_SAAS_URL, verify=True, log_level=API_LOG_LEVEL):
+    def __init__(self, api_token, url=TFC_SAAS_URL, verify=True, log_level=TERRASNEK_LOG_LEVEL):
         if api_token is None:
             raise InvalidTFCTokenException
 
@@ -136,10 +157,17 @@ class TFC():
         self._logger.debug("Initializing the TFC API class...")
 
         self._instance_url = url
+
+        parsed_url = urlparse(url)
+        self._hostname = parsed_url.netloc
+
         self._token = api_token
         self._current_org = None
         self._verify = verify
 
+        self.__version__ = TERRASNEK_VERSION
+        self.version = TERRASNEK_VERSION
+
         self.admin_module_sharing: TFCAdminModuleSharing = None
         self.admin_orgs: TFCAdminOrgs = None
         self.admin_runs: TFCAdminRuns = None
@@ -156,11 +184,13 @@ class TFC():
         self.applies: TFCApplies = None
         self.agents: TFCAgents = None
         self.agent_tokens: TFCAgentTokens = None
+        self.comments: TFCComments = None
         self.config_versions: TFCConfigVersions = None
         self.cost_estimates: TFCCostEstimates = None
         self.oauth_clients: TFCOAuthClients = None
         self.oauth_tokens: TFCOAuthTokens = None
         self.org_memberships: TFCOrgMemberships = None
+        self.org_tags: TFCOrgTags = None
         self.org_tokens: TFCOrgTokens = None
         self.plans: TFCPlans = None
         self.plan_exports: TFCPlanExports = None
@@ -168,8 +198,11 @@ class TFC():
         self.policy_checks: TFCPolicyChecks = None
         self.policy_sets: TFCPolicySets = None
         self.policy_set_params: TFCPolicySetParams = None
+        self.registry_providers: TFCRegistryProviders = None
         self.notification_configs: TFCNotificationConfigurations = None
         self.registry_modules: TFCRegistryModules = None
+        self.run_tasks: TFCRunTasks = None
+        self.run_tasks_integration: TFCRunTasksIntegration = None
         self.run_triggers: TFCRunTriggers = None
         self.runs: TFCRuns = None
         self.state_versions: TFCStateVersions = None
@@ -182,7 +215,10 @@ class TFC():
         self.users: TFCUsers = None
         self.user_tokens: TFCUserTokens = None
         self.vars: TFCVars = None
+        self.var_sets: TFCVarSets = None
+        self.vcs_events: TFCVCSEvents = None
         self.workspace_vars: TFCWorkspaceVars = None
+        self.workspace_resources: TFCWorkspaceResources = None
         self.workspaces: TFCWorkspaces = None
 
         self._token = None
@@ -238,6 +274,12 @@ class TFC():
         """
         return self._instance_url
 
+    def get_hostname(self):
+        """
+        Allows for the user to retrieve the hostname being hit from the API object.
+        """
+        return self._hostname
+
     def set_org(self, org_name):
         """
         Sets the organization to use for org specific endpoints.
@@ -293,6 +335,7 @@ class TFC():
         self._token = token
         self._headers = {
             "Authorization": f"Bearer {token}",
+            "User-Agent": f"terrasnek-{self.version}",
             "Content-Type": "application/vnd.api+json"
         }
         self._initialize_endpoints()
@@ -304,6 +347,9 @@ class TFC():
         return self._token
 
     def is_terraform_cloud(self):
+        """
+        Returns true if this API instance is configured for Terraform Cloud.
+        """
         return TFC_SAAS_HOSTNAME in self._instance_url
 
 
