@@ -4,7 +4,6 @@ Module for Terraform Cloud API Endpoint: Config Versions.
 import io
 import tarfile
 from .endpoint import TFCEndpoint
-from ._constants import MAX_PAGE_SIZE
 
 class TFCConfigVersions(TFCEndpoint):
     """
@@ -16,6 +15,7 @@ class TFCConfigVersions(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._ws_api_v2_base_url = f"{self._api_v2_base_url}/workspaces"
         self._config_version_api_v2_base_url = f"{self._api_v2_base_url}/configuration-versions"
+        self._runs_api_v2_base_url = f"{self._api_v2_base_url}/runs"
 
     def required_entitlements(self):
         return []
@@ -26,45 +26,32 @@ class TFCConfigVersions(TFCEndpoint):
     def terraform_enterprise_only(self):
         return False
 
-    def list(self, workspace_id, page=None, page_size=None):
+    def list(self, workspace_id, page=None, page_size=None, include=None):
         """
         ``GET /workspaces/:workspace_id/configuration-versions``
 
         `Config Versions List API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/configuration-versions.html#list-configuration-versions>`_
 
-        Query Parameter(s) (`details \
-            <https://www.terraform.io/docs/cloud/api/configuration-versions.html#query-parameters>`_):
-            - ``page`` (Optional)
-            - ``page_size`` (Optional)
+        `Query Parameter(s) Details \
+            <https://www.terraform.io/docs/cloud/api/configuration-versions.html#query-parameters>`__
         """
         url = f"{self._ws_api_v2_base_url}/{workspace_id}/configuration-versions"
-        return self._list(url, page=page, page_size=page_size)
+        return self._list(url, page=page, page_size=page_size, include=include)
 
-    def list_all(self, workspace_id):
+    def list_all(self, workspace_id, include=None):
         """
         This function does not correlate to an endpoint in the TFC API Docs specifically,
         but rather is a helper function to wrap the `list` endpoint, which enumerates out
         every page so users do not have to implement the paging logic every time they just
         want to list every config version in a workspace.
 
-        Returns an array of objects.
+        Returns an object with two arrays of objects.
         """
-        current_page_number = 1
-        config_versions_resp = \
-            self.list(workspace_id, page=current_page_number, page_size=MAX_PAGE_SIZE)
-        total_pages = config_versions_resp["meta"]["pagination"]["total-pages"]
+        url = f"{self._ws_api_v2_base_url}/{workspace_id}/configuration-versions"
+        return self._list_all(url, include=include)
 
-        config_versions = []
-        while current_page_number <= total_pages:
-            config_versions_resp = \
-                self.list(workspace_id, page=current_page_number, page_size=MAX_PAGE_SIZE)
-            config_versions += config_versions_resp["data"]
-            current_page_number += 1
-
-        return config_versions
-
-    def show(self, config_version_id):
+    def show(self, config_version_id, include=None):
         """
         ``GET /configuration-versions/:configuration-id``
 
@@ -72,7 +59,18 @@ class TFCConfigVersions(TFCEndpoint):
             <https://www.terraform.io/docs/cloud/api/configuration-versions.html#show-a-configuration-version>`_
         """
         url = f"{self._config_version_api_v2_base_url}/{config_version_id}"
-        return self._show(url)
+        return self._show(url, include=include)
+
+    def show_config_version_commit_info(self, config_version_id, include=None):
+        """
+        ``GET /configuration-versions/:configuration-id/ingress-attributes``
+        ``GET /configuration-versions/:configuration-id?include=ingress-attributes``
+
+        `Config Versions Show Commit Information API Doc Reference \
+            <https://www.terraform.io/docs/cloud/api/configuration-versions.html#show-a-configuration-version-39-s-commit-information>`_
+        """
+        url = f"{self._config_version_api_v2_base_url}/{config_version_id}/ingress-attributes"
+        return self._show(url, include=include)
 
     def create(self, workspace_id, payload):
         """
@@ -138,3 +136,28 @@ class TFCConfigVersions(TFCEndpoint):
 
         # upload the template
         return self._put(upload_url, data=targz_io.read())
+
+    def archive_version(self, config_version_id):
+        """
+        ``POST /configuration-versions/:configuration_version_id/actions/archive``
+
+        `Config Versions Archive Version API Doc Reference \
+            <https://www.terraform.io/cloud-docs/api-docs/configuration-versions#archive-a-configuration-version>`_
+        """
+        url = f"{self._config_version_api_v2_base_url}/{config_version_id}/actions/archive"
+        return self._post(url)
+
+    def download_version_files(self, config_version_id=None, run_id=None):
+        """
+        ``GET /configuration-versions/:configuration_version_id/download``
+        ``GET /runs/:run_id/configuration-version/download``
+
+        `Config Versions Download Files API Doc Reference \
+            <https://www.terraform.io/cloud-docs/api-docs/configuration-versions#download-configuration-files>`_
+        """
+        if config_version_id is not None:
+            url = f"{self._config_version_api_v2_base_url}/{config_version_id}/download"
+        elif run_id is not None:
+            url = f"{self._runs_api_v2_base_url}/{run_id}/configuration-version/download"
+
+        return self._get(url)
