@@ -17,8 +17,8 @@ from ._constants import \
     HTTP_OK, HTTP_CREATED, HTTP_ACCEPTED, HTTP_NO_CONTENT, HTTP_BAD_REQUEST, HTTP_UNAUTHORIZED, \
         HTTP_FORBIDDEN, HTTP_NOT_FOUND, HTTP_CONFLICT, HTTP_PRECONDITION_FAILED, \
             HTTP_UNPROCESSABLE_ENTITY, HTTP_API_REQUEST_RATE_LIMIT_REACHED, \
-                HTTP_INTERNAL_SERVER_ERROR
-
+                HTTP_INTERNAL_SERVER_ERROR, MAX_PAGE_SIZE, HTTP_MOVED_PERMANENTLY, \
+                    HTTP_MOVED_TEMPORARILY
 
 class TFCEndpoint(ABC):
     """
@@ -61,12 +61,13 @@ class TFCEndpoint(ABC):
         return False
 
     def _delete(self, url, data=None):
-        results = None
         req = requests.delete(\
             url, data=json.dumps(data), headers=self._headers, verify=self._verify)
 
-        if req.status_code == HTTP_NO_CONTENT:
-            pass
+        if req.status_code == HTTP_OK:
+            self._logger.debug(f"Terraform Cloud resource at URL [{url}] destroyed.")
+        elif req.status_code == HTTP_NO_CONTENT:
+            self._logger.debug(f"Terraform Cloud resource at URL [{url}] destroyed.")
         elif req.status_code == HTTP_NOT_FOUND:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -80,15 +81,82 @@ class TFCEndpoint(ABC):
             self._logger.debug(err)
             raise TFCHTTPAPIRequestRateLimit(err)
         else:
-            err = json.loads(req.content.decode("utf-8"))
+            try:
+                err = json.loads(req.content.decode("utf-8"))
+            except json.decoder.JSONDecodeError:
+                err = req.content
             self._logger.debug(err)
             raise TFCHTTPUnclassified(err)
 
-        return results
+    # pylint: disable=too-many-statements,too-many-branches
+    def _get(self, url, return_raw=None, allow_redirects=None, query=None, filters=None, \
+        page=None, page_size=None, search=None, include=None, sort=None, \
+        offset=None, limit=None, provider=None, namespace=None, verified=None, \
+        since=None):
 
-    def _get(self, url, return_raw=False, allow_redirects=False):
         results = None
 
+        q_options = []
+
+        if query is not None:
+            q_options.append(f"q={query}")
+
+        if filters is not None:
+            if isinstance(filters, list):
+                if filters:
+                    for fil in filters:
+                        filter_string = "filter"
+                        for k in fil["keys"]:
+                            filter_string += f"[{k}]"
+                        filter_string += f"={fil['value']}"
+                        q_options.append(filter_string)
+            else:
+                raise TypeError("The `filters` parameter must be of `list` type.")
+
+        if include is not None:
+            if isinstance(include, list):
+                if include:
+                    joined_include = ",".join(include)
+                    q_options.append(f"include={joined_include}")
+            else:
+                raise TypeError("The `include` parameter must be of `list` type.")
+
+        if page is not None:
+            q_options.append(f"page[number]={page}")
+
+        if page_size is not None:
+            q_options.append(f"page[size]={page_size}")
+
+        if sort is not None:
+            q_options.append(f"sort={sort}")
+
+        if search is not None:
+            q_options.append(f"search[name]={search}")
+
+        if since is not None:
+            q_options.append(f"since={since}")
+
+        # V1 Modules API options
+        # NOTE: The `offset` parameter is not in use very much now, but remains for
+        # backwards compatibility.
+        if offset is not None:
+            q_options.append(f"offset={offset}")
+
+        if limit is not None:
+            q_options.append(f"limit={limit}")
+
+        if provider is not None:
+            q_options.append(f"provider={provider}")
+
+        if namespace is not None:
+            q_options.append(f"namespace={namespace}")
+
+        if verified is not None:
+            q_options.append(f"verified={verified}")
+
+        if q_options:
+            url += "?" + "&".join(q_options)
+
         self._logger.debug(f"Trying HTTP GET to URL: {url} ...")
         req = requests.get(\
             url, headers=self._headers, verify=self._verify, allow_redirects=allow_redirects)
@@ -102,9 +170,15 @@ class TFCEndpoint(ABC):
             results = req.headers
         elif req.history:
             # NOTE: If we got redirected, run the get on the new URL, and fix the
-            # URL to match the private module registry URL schema.
+            # URL to match the private module registry URL schema. At some point
+            # in the future, this may need to use HTTP_MOVED_TEMPORARILY.
             url = req.url.replace("/v1/modules/", "/api/registry/v1/modules/")
             results = {"redirect-url": url}
+        elif req.status_code == HTTP_MOVED_TEMPORARILY:
+            results = req.content.decode("utf-8")
+        elif req.status_code == HTTP_MOVED_PERMANENTLY:
+            # TODO: this isn't doing anything now? (this was found in using run-tasks from event-hooks)
+            pass
         elif req.status_code == HTTP_UNAUTHORIZED:
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
@@ -118,11 +192,15 @@ class TFCEndpoint(ABC):
             self._logger.debug(err)
             raise TFCHTTPAPIRequestRateLimit(err)
         else:
-            err = json.loads(req.content.decode("utf-8"))
+            try:
+                err = json.loads(req.content.decode("utf-8"))
+            except json.decoder.JSONDecodeError:
+                err = req.content
             self._logger.debug(err)
             raise TFCHTTPUnclassified(err)
 
         return results
+    # pylint: disable=too-many-statements,too-many-branches
 
     def _patch(self, url, data=None):
         results = None
@@ -148,8 +226,13 @@ class TFCEndpoint(ABC):
             err = json.loads(req.content.decode("utf-8"))
             self._logger.debug(err)
             raise TFCHTTPAPIRequestRateLimit(err)
+        elif req.status_code == HTTP_NO_CONTENT:
+            pass
         else:
-            err = json.loads(req.content.decode("utf-8"))
+            try:
+                err = json.loads(req.content.decode("utf-8"))
+            except json.decoder.JSONDecodeError:
+                err = req.content
             self._logger.debug(err)
             raise TFCHTTPUnclassified(err)
 
@@ -195,7 +278,10 @@ class TFCEndpoint(ABC):
             self._logger.debug(err)
             raise TFCHTTPInternalServerError(err)
         else:
-            err = json.loads(req.content.decode("utf-8"))
+            try:
+                err = json.loads(req.content.decode("utf-8"))
+            except json.decoder.JSONDecodeError:
+                err = req.content
             self._logger.debug(err)
             raise TFCHTTPUnclassified(err)
 
@@ -221,7 +307,10 @@ class TFCEndpoint(ABC):
             self._logger.debug(err)
             raise TFCHTTPAPIRequestRateLimit(err)
         else:
-            err = json.loads(req.content.decode("utf-8"))
+            try:
+                err = json.loads(req.content.decode("utf-8"))
+            except json.decoder.JSONDecodeError:
+                err = req.content
             self._logger.debug(err)
             raise TFCHTTPUnclassified(err)
 
@@ -236,23 +325,14 @@ class TFCEndpoint(ABC):
 
         return self._post(url, data=payload)
 
-    def _destroy(self, url):
+    def _destroy(self, url, data=None):
         """
         Implementation of the common destroy resource pattern for the TFC API.
-        """
-        req = requests.delete(url, headers=self._headers, verify=self._verify)
 
-        valid_status_codes = [HTTP_OK, HTTP_NO_CONTENT]
-        if req.status_code in valid_status_codes:
-            self._logger.debug(f"Terraform Cloud resource at URL [{url}] destroyed.")
-        elif req.status_code == HTTP_API_REQUEST_RATE_LIMIT_REACHED:
-            err = json.loads(req.content.decode("utf-8"))
-            self._logger.debug(err)
-            raise TFCHTTPAPIRequestRateLimit(err)
-        else:
-            err = json.loads(req.content.decode("utf-8"))
-            self._logger.debug(err)
-            raise TFCHTTPUnclassified(err)
+        NOTE: This is basically an alias to the _delete method, but is more
+        along the verbiage used in the docs.
+        """
+        self._delete(url, data=data)
 
     def _list(self, url, query=None, filters=None, \
         page=None, page_size=None, search=None, include=None, sort=None, \
@@ -261,67 +341,53 @@ class TFCEndpoint(ABC):
         """
         Implementation of the common list resources pattern for the TFC API.
         """
+        return self._get(url, query=query, filters=filters, page=page, \
+            page_size=page_size, search=search, include=include, sort=sort, \
+                offset=offset, limit=limit, provider=provider, namespace=namespace, \
+                    verified=verified, since=since)
 
-        q_options = []
+    def _list_all(self, url, include=None, search=None, filters=None, query=None):
+        """
+        This function does not correlate to an endpoint in the TFC API Docs specifically,
+        but rather is a helper function to wrap the `list` endpoint, which enumerates out
+        every page so users do not have to implement the paging logic every time they just
+        want to list every workspace in an organization.
 
-        if query is not None:
-            q_options.append(f"q={query}")
+        Returns an object with two arrays of objects.
+        """
+        current_page_number = 1
+        list_resp = \
+            self._list(url, page=current_page_number, page_size=MAX_PAGE_SIZE, include=include, \
+                search=search, filters=filters, query=query)
 
-        if filters is not None:
-            for fil in filters:
-                filter_string = "filter"
-                for k in fil["keys"]:
-                    filter_string += f"[{k}]"
-                filter_string += f"={fil['value']}"
-                q_options.append(filter_string)
+        if "meta" in list_resp:
+            total_pages = list_resp["meta"]["pagination"]["total-pages"]
+        elif "pagination" in list_resp:
+            total_pages = list_resp["pagination"]["total_pages"]
 
-        if page is not None:
-            q_options.append(f"page[number]={page}")
+        included = []
+        data = []
+        while current_page_number <= total_pages:
+            list_resp = \
+                self._list(url, page=current_page_number, page_size=MAX_PAGE_SIZE, \
+                    include=include, search=search, filters=filters, query=query)
+            data += list_resp["data"]
 
-        if page_size is not None:
-            q_options.append(f"page[size]={page_size}")
+            if "included" in list_resp:
+                included += list_resp["included"]
 
-        if search is not None:
-            q_options.append(f"page[name]={page_size}")
+            current_page_number += 1
 
-        if include is not None:
-            q_options.append(f"include={include}")
+        return {
+            "data": data,
+            "included": included
+        }
 
-        if sort is not None:
-            q_options.append(f"sort={sort}")
-
-        if search is not None:
-            q_options.append(f"search[name]={search}")
-
-        if since is not None:
-            q_options.append(f"since={since}")
-
-        # V1 Modules API options
-        if offset is not None:
-            q_options.append(f"offset={offset}")
-
-        if limit is not None:
-            q_options.append(f"limit={limit}")
-
-        if provider is not None:
-            q_options.append(f"provider={provider}")
-
-        if namespace is not None:
-            q_options.append(f"namespace={namespace}")
-
-        if verified is not None:
-            q_options.append(f"verified={verified}")
-
-        if q_options:
-            url += "?" + "&".join(q_options)
-
-        return self._get(url)
-
-    def _show(self, url):
+    def _show(self, url, include=None):
         """
         Implementation of the common show resource pattern for the TFC API.
         """
-        return self._get(url)
+        return self._get(url, include=include)
 
     def _update(self, url, payload):
         """
