@@ -31,11 +31,6 @@ class TFCUserTokens(TFCEndpoint):
         `User Tokens Create API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/user-tokens.html#create-a-user-token>`_
 
-        NOTE: the following method descriptor is here for the ``api_comparison.py`` script to pass,
-        since it uses a different prefix than the majority of endpoints.
-
-        ``POST /api/v2/users/:user_id/authentication-tokens``
-
         `Create Sample Payload \
             <https://www.terraform.io/docs/cloud/api/user-tokens.html#sample-payload>`_
         """
@@ -49,10 +44,6 @@ class TFCUserTokens(TFCEndpoint):
         `User Tokens Destroy API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/user-tokens.html#destroy-a-user-token>`_
 
-        NOTE: the following method descriptor is here for the ``api_comparison.py`` script to pass,
-        since it uses a different prefix than the majority of endpoints.
-
-        ``DELETE /api/v2/authentication-tokens/:id``
         """
         url = f"{self._tokens_api_v2_base_url}/{token_id}"
         self._destroy(url)
@@ -64,10 +55,6 @@ class TFCUserTokens(TFCEndpoint):
         `User Tokens List API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/user-tokens.html#list-user-tokens>`_
 
-        NOTE: the following method descriptor is here for the ``api_comparison.py`` script to pass,
-        since it uses a different prefix than the majority of endpoints.
-
-        ``GET /api/v2/users/:user_id/authentication-tokens``
         """
         url = f"{self._users_api_v2_base_url}/{user_id}/authentication-tokens"
         return self._list(url)
@@ -78,11 +65,6 @@ class TFCUserTokens(TFCEndpoint):
 
         `User Tokens Show API Doc Reference \
             <https://www.terraform.io/docs/cloud/api/user-tokens.html#show-a-user-token>`_
-
-        NOTE: the following method descriptor is here for the ``api_comparison.py`` script to pass,
-        since it uses a different prefix than the majority of endpoints.
-
-        ``GET /api/v2/authentication-tokens/:id``
         """
         url = f"{self._tokens_api_v2_base_url}/{token_id}"
         return self._show(url)
