@@ -7,7 +7,7 @@ import sys
 import logging
 
 # Test Defaults
-API_LOG_LEVEL = logging.INFO
+TERRASNEK_LOG_LEVEL = logging.INFO
 
 
 # Configurable Constants
@@ -29,7 +29,6 @@ SMTP_USERNAME = os.getenv("SMTP_USERNAME", None)
 SMTP_PASSWORD = os.getenv("SMTP_PASSWORD", None)
 
 GITHUB_TOKEN = os.getenv("GITHUB_TOKEN", None)
-GITHUB_SECRET = os.getenv("GITHUB_SECRET", None)
 
 # NOTE: This is an optional env var, if not provided a random test org will be generated
 TEST_ORG_NAME = os.getenv("TEST_ORG_NAME", None)
@@ -72,9 +71,6 @@ if SMTP_PASSWORD is None:
 if GITHUB_TOKEN is None:
     sys.exit("Environment variable GITHUB_TOKEN must be set.")
 
-if GITHUB_SECRET is None:
-    sys.exit("Environment variable GITHUB_SECRET must be set.")
-
 if TEST_EMAIL is None:
     sys.exit("Environment variable TEST_EMAIL must be set.")
 
@@ -92,3 +88,5 @@ if TEST_PASSWORD is None:
 TFE_MODULE_PROVIDER_TYPE = "tfe"
 DEFAULT_VCS_WORKING_DIR = "tfe"
 MAX_TEST_TIMEOUT = 300
+PAGE_START = 0
+PAGE_SIZE = 50
