@@ -20,9 +20,8 @@ from terrasnek._constants import Entitlements
 from ._constants import \
     TFC_TOKEN, TFC_ORG_TOKEN, TFC_URL, TEST_EMAIL, \
     TEST_ORG_NAME, TEST_USERNAME, TEST_TEAM_NAME, \
-    GITHUB_TOKEN, GITHUB_SECRET, \
-    SSL_VERIFY, TEST_PASSWORD, MAX_TEST_TIMEOUT, \
-    DEFAULT_VCS_WORKING_DIR, API_LOG_LEVEL
+    GITHUB_TOKEN, SSL_VERIFY, TEST_PASSWORD, MAX_TEST_TIMEOUT, \
+    DEFAULT_VCS_WORKING_DIR, TERRASNEK_LOG_LEVEL
 
 class TestTFCBaseTestCase(unittest.TestCase):
     """
@@ -37,17 +36,17 @@ class TestTFCBaseTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls._logger = logging.getLogger(cls.__class__.__name__)
-        cls._logger.setLevel(API_LOG_LEVEL)
+        cls._logger.setLevel(TERRASNEK_LOG_LEVEL)
         cls._tfc_url = TFC_URL
 
         cls._test_api_token = TFC_TOKEN
         cls._test_api_org_token = TFC_ORG_TOKEN
-        cls._api_log_level = API_LOG_LEVEL
+        cls._TERRASNEK_LOG_LEVEL = TERRASNEK_LOG_LEVEL
         cls._ssl_verify = SSL_VERIFY
 
         cls._api = TFC(\
             cls._test_api_token, url=cls._tfc_url, \
-                verify=cls._ssl_verify, log_level=cls._api_log_level)
+                verify=cls._ssl_verify, log_level=cls._TERRASNEK_LOG_LEVEL)
 
         cls._test_username = TEST_USERNAME
         cls._test_email = TEST_EMAIL
@@ -78,6 +77,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
         # a new one to run the testing in.
         if TEST_ORG_NAME:
             cls._test_org_name = TEST_ORG_NAME
+            cls._test_org = cls._api.orgs.show(cls._test_org_name)
         else:
             cls._test_org_name = cls._random_name()
             org_create_payload = {
@@ -105,12 +105,13 @@ class TestTFCBaseTestCase(unittest.TestCase):
 
         if cls._api.is_terraform_cloud() and endpoint_to_test.terraform_enterprise_only():
             raise unittest.SkipTest(\
-                (f"Skipping Test (%s), since we're testing against Terraform Cloud." % cls._endpoint_being_tested))
-        elif not cls._api.is_terraform_cloud() and endpoint_to_test.terraform_cloud_only():
+                (f"Skipping Test (%s), since we're testing against Terraform Cloud." % \
+                    cls._endpoint_being_tested))
+
+        if not cls._api.is_terraform_cloud() and endpoint_to_test.terraform_cloud_only():
             raise unittest.SkipTest(\
-                (f"Skipping Test (%s), since we're testing against Terraform Enterprise." % cls._endpoint_being_tested))
-        else:
-            cls._logger.debug("Endpoint", cls._endpoint_being_tested, " not expected.")
+                (f"Skipping Test (%s), since we're testing against Terraform Enterprise." % \
+                    cls._endpoint_being_tested))
 
         cls._purge_organization()
 
@@ -128,23 +129,24 @@ class TestTFCBaseTestCase(unittest.TestCase):
             f"Purging test org ({cls._test_org_name}) of all resources to start fresh...")
 
         cls._logger.info(f"Purging test org ({cls._test_org_name}) of workspaces...")
-        workspaces = cls._api.workspaces.list_all()
+        workspaces = cls._api.workspaces.list_all()["data"]
         for workspace in workspaces:
             cls._api.workspaces.destroy(workspace_id=workspace["id"])
         cls._logger.debug(f"Workspaces purged from test org ({cls._test_org_name}).")
 
         cls._purge_module_registry()
+        cls._purge_provider_registry()
 
         cls._logger.debug(f"Modules purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of policies...")
-        policies = cls._api.policies.list_all()
+        policies = cls._api.policies.list_all()["data"]
         for policy in policies:
             cls._api.policies.destroy(policy["id"])
         cls._logger.debug(f"Policies purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of policy sets...")
-        policy_sets = cls._api.policy_sets.list_all()
+        policy_sets = cls._api.policy_sets.list_all()["data"]
         for policy_set in policy_sets:
             cls._api.policy_sets.destroy(policy_set["id"])
         cls._logger.debug(f"Policy sets purged from test org ({cls._test_org_name}).")
@@ -172,38 +174,64 @@ class TestTFCBaseTestCase(unittest.TestCase):
         cls._logger.debug(f"Teams purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of org membership invites...")
-        org_memberships = cls._api.org_memberships.list_all_for_org()
-        for org_memberships in org_memberships:
-            membership_id = org_memberships["id"]
-            member_status = org_memberships["attributes"]["status"]
+        org_memberships = cls._api.org_memberships.list_all_for_org()["data"]
+        for org_membership in org_memberships:
+            membership_id = org_membership["id"]
+            member_status = org_membership["attributes"]["status"]
             if member_status == "invited":
                 cls._api.org_memberships.remove(membership_id)
         cls._logger.debug(f"Org member invites purged from test org ({cls._test_org_name}).")
 
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
+        agent_pools = cls._api.agents.list_pools()["data"]
+        for agent_pool in agent_pools:
+            cls._api.agents.destroy_pool(agent_pool["id"])
+        cls._logger.debug(f"Agent pools purged from test org ({cls._test_org_name}).")
+
+        # FIXME: move these once they both go GA
         if cls._api.is_terraform_cloud():
-            cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
-            agent_pools = cls._api.agents.list_pools()["data"]
-            for agent_pool in agent_pools:
-                cls._api.agents.destroy(agent_pool["id"])
-            cls._logger.debug(f"Agent pools purged from test org ({cls._test_org_name}).")
+            cls._logger.debug(f"Purging test org ({cls._test_org_name}) of run tasks...")
+            run_tasks = cls._api.run_tasks.list_all()["data"]
+            for run_task in run_tasks:
+                cls._api.run_tasks.destroy(run_task["id"])
+            cls._logger.debug(f"Run tasks purged from test org ({cls._test_org_name}).")
+
+            cls._logger.debug(f"Purging test org ({cls._test_org_name}) of variable sets...")
+            var_sets = cls._api.var_sets.list_for_org()["data"]
+            for var_set in var_sets:
+                var_set_id = var_set["id"]
+                cls._api.var_sets.destroy(var_set_id)
+            cls._logger.debug(f"Variable sets purged from test org ({cls._test_org_name}).")
 
         try:
             cls._logger.debug(f"Purging org token from test org ({cls._test_org_name})...")
             cls._api.org_tokens.destroy()
             cls._logger.debug(f"Org token purged from test org ({cls._test_org_name}).")
-        except terrasnek.exceptions.TFCHTTPUnclassified:
+        except terrasnek.exceptions.TFCHTTPNotFound:
             cls._logger.debug(f"No org token exists for test org ({cls._test_org_name})...")
 
     @classmethod
     def _purge_module_registry(cls):
-        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of modules...")
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of registry modules...")
         try:
-            registry_modules_resp = cls._api.registry_modules.list()
-            registry_modules = registry_modules_resp["modules"]
+            registry_modules = cls._api.registry_modules.list()["data"]
             for registry_module in registry_modules:
-                cls._api.registry_modules.destroy(registry_module["name"])
+                cls._api.registry_modules.destroy(registry_module["attributes"]["name"])
         except terrasnek.exceptions.TFCHTTPNotFound:
-            cls._logger.debug("No modules exist in this org, skipping.")
+            cls._logger.debug("No registry modules exist in this org, skipping.")
+
+    @classmethod
+    def _purge_provider_registry(cls):
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of registry providers...")
+        try:
+            registry_providers = cls._api.registry_providers.list()["data"]
+            for registry_provider in registry_providers:
+                registry_name = registry_provider["attributes"]["registry-name"]
+                namespace = registry_provider["attributes"]["namespace"]
+                name = registry_provider["attributes"]["name"]
+                cls._api.registry_providers.destroy(registry_name, namespace, name)
+        except terrasnek.exceptions.TFCHTTPNotFound:
+            cls._logger.debug("No registry providers exist in this org, skipping.")
 
     @classmethod
     def _get_missing_entitlements(cls, endpoint_attr_name):
@@ -242,10 +270,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
     def _get_config_version_create_payload():
         return {
             "data": {
-                "type": "configuration-versions",
-                "attributes": {
-                    "auto-queue-runs": False
-                }
+                "type": "configuration-versions"
             }
         }
 
@@ -335,24 +360,26 @@ class TestTFCBaseTestCase(unittest.TestCase):
             "data": {
                 "attributes": {
                     "name": self._unittest_random_name(),
-                    "terraform_version": "0.12.24",
+                    "terraform_version": "1.0.3",
                     "working-directory": working_dir,
                     "vcs-repo": {
                         "identifier": "dahlke/terrasnek-unittest-config",
                         "oauth-token-id": oauth_token_id,
                         "branch": "master"
-                    }
+                    },
+                    "global-remote-state": False
                 },
                 "type": "workspaces"
             }
         }
 
-    def _get_ws_without_vcs_create_payload(self):
+    def _get_ws_no_vcs_create_payload(self):
         return {
             "data": {
                 "type": "workspaces",
                 "attributes": {
-                    "name": self._unittest_random_name()
+                    "name": self._unittest_random_name(),
+                    "global-remote-state": False
                 }
             }
         }
@@ -470,7 +497,6 @@ class TestTFCBaseTestCase(unittest.TestCase):
                     "service-provider": "github",
                     "http-url": "https://github.com",
                     "api-url": "https://api.github.com",
-                    "secret": GITHUB_SECRET,
                     "oauth-token-string": GITHUB_TOKEN
                 }
             }
@@ -479,15 +505,129 @@ class TestTFCBaseTestCase(unittest.TestCase):
     @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
     def _created_run_timeout(self, run_id):
         """
-        While running the tests, it's possible that a run gets queued, which
-        would cause the test suite to stall indefinitely until the queue is cleared.
-        This function is meant to keep that to a minimum, and just fail the test
-        if we are waiting too long.
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        terraform plans to occur after creating a run.
         """
         created_run = self._api.runs.show(run_id)["data"]
-        while not created_run["attributes"]["actions"]["is-confirmable"]:
+        while not created_run["attributes"]["status"] == "planned_and_finished" and \
+            not created_run["attributes"]["actions"]["is-confirmable"]:
             created_run = self._api.runs.show(run_id)["data"]
             self._logger.debug("Waiting for created run to finish planning...")
             time.sleep(1)
         self._logger.debug("Plan successful.")
         return created_run
+
+    @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
+    def _applied_run_timeout(self, run_id):
+        """
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        terraform plans to occur after creating a run.
+        """
+        applied_run = self._api.runs.show(run_id)["data"]
+        while not applied_run["attributes"]["status"] == "applied":
+            applied_run = self._api.runs.show(run_id)["data"]
+            self._logger.debug("Waiting for created run to finish applying...")
+            time.sleep(1)
+        self._logger.debug("Apply successful.")
+        return applied_run
+
+    @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
+    def _locked_workspace_timeout(self, ws_id):
+        """
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        terraform plans to occur after creating a run.
+        """
+        workspace = self._api.workspaces.show(workspace_id=ws_id)["data"]
+        while workspace["attributes"]["locked"]:
+            workspace = self._api.workspaces.show(workspace_id=ws_id)["data"]
+            self._logger.debug("Waiting for workspace to be unlocked...")
+            time.sleep(1)
+        self._logger.debug("Workspace unlocked.")
+        return workspace
+
+    @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
+    def _found_module_in_listed_modules_timeout(self, name_to_check):
+        """
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        listing published modules.
+        """
+        found_module = False
+        # TODO: test other parameters
+        listed_modules = self._api.registry_modules.list()["data"]
+        self._logger.debug("Searching for published module...")
+
+        while True:
+            for module in listed_modules:
+                if module["attributes"]["name"] == name_to_check:
+                    found_module = True
+                    self._logger.debug("Published module found.")
+                    break
+
+            if found_module:
+                break
+
+            self._logger.debug("Waiting for published module to return in API results...")
+            time.sleep(1)
+
+            listed_modules = self._api.registry_modules.list()["data"]
+
+        return listed_modules, found_module
+
+    @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
+    def _search_published_module_timeout(self, published_module_name):
+        """
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        searching for published modules in the private module registry.
+        """
+        search_modules_resp = self._api.registry_modules.search(published_module_name)
+        search_modules = search_modules_resp["modules"]
+        found_module = False
+        self._logger.debug("Searching for published module...")
+
+        while True:
+            for module in search_modules:
+                if module["namespace"] == published_module_name:
+                    found_module = True
+                    self._logger.debug("Published module found.")
+                    break
+
+            if found_module:
+                break
+
+            self._logger.debug("Waiting for published module to return in API results...")
+            time.sleep(1)
+            search_modules_resp = self._api.registry_modules.search(published_module_name)
+            search_modules = search_modules_resp["modules"]
+
+        return search_modules, found_module
+
+    @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
+    def _state_versions_includes_timeout(self, filters, include=None, list_all=False):
+        """
+        Due to eventual consistency in TFC, it can take a few seconds for the state returned
+        from the API to match the expected output. This function provides some time cushion for
+        state versions to process the includes.
+        """
+        if list_all:
+            state_versions_raw = self._api.state_versions.list_all(filters=filters, include=include)
+        else:
+            state_versions_raw = self._api.state_versions.list(filters=filters, include=include)
+
+        found_includes = False
+
+        while not found_includes:
+            found_includes = "included" in state_versions_raw
+            self._logger.debug("Waiting for the includes to be returned with the state version API results...")
+            time.sleep(1)
+
+            if list_all:
+                state_versions_raw = self._api.state_versions.list_all(filters=filters, include=include)
+            else:
+                state_versions_raw = self._api.state_versions.list(filters=filters, include=include)
+
+        return state_versions_raw, found_includes
