@@ -1,14 +1,15 @@
+# pylint: disable=too-many-locals
+
 """
 Module for Terraform Cloud API Endpoint: Registry Modules.
 """
 
 import time
 import os
-import timeout_decorator
 
 from terrasnek.exceptions import TFCHTTPNotFound
 from .base import TestTFCBaseTestCase
-from ._constants import TFE_MODULE_PROVIDER_TYPE, MAX_TEST_TIMEOUT
+from ._constants import TFE_MODULE_PROVIDER_TYPE
 
 class TestTFCRegistryModules(TestTFCBaseTestCase):
     """
@@ -44,9 +45,9 @@ class TestTFCRegistryModules(TestTFCBaseTestCase):
             "data": {
                 "attributes": {
                     "vcs-repo": {
-                        "identifier": "dahlke/terraform-tfe-terrasnek-unittest-6",
+                        "identifier": "dahlke/terraform-tfe-terrasnek-unittest",
                         "oauth-token-id": self._oauth_token_id,
-                        "display_identifier": "dahlke/terraform-tfe-terrasnek-unittest-6"
+                        "display_identifier": "dahlke/terraform-tfe-terrasnek-unittest"
                     }
                 },
                 "type":"registry-modules"
@@ -57,49 +58,31 @@ class TestTFCRegistryModules(TestTFCBaseTestCase):
         published_module_name = published_module["attributes"]["name"]
         self.assertEqual("registry-modules", published_module["type"])
 
+        # Allow a couple seconds for the VCS and TFE to sync up
+        time.sleep(3)
+
         # Test the listing of the modules, time out if it takes too long.
         # List all the modules for this org, confirm we found the one we
         # published.
-        @timeout_decorator.timeout(MAX_TEST_TIMEOUT)
-        def found_module_in_listed_modules_timeout(name_to_check):
-            found_module = False
-            listed_modules_resp = self._api.registry_modules.list()
-            listed_modules = listed_modules_resp["modules"]
+        _, found_module_in_loop = self._found_module_in_listed_modules_timeout(published_module_name)
 
-            while True:
-                listed_modules_resp = self._api.registry_modules.list()
-                listed_modules = listed_modules_resp["modules"]
+        self.assertTrue(found_module_in_loop)
 
-                for module in listed_modules:
-                    if module["name"] == name_to_check:
-                        found_module = True
-                        break
-
-                if found_module:
-                    break
-
-                time.sleep(1)
-            return listed_modules, found_module
-        listed_modules, found_module = found_module_in_listed_modules_timeout(published_module_name)
-
-        self.assertTrue(found_module)
+        # List all the modules, confirm there is only the one we created
+        all_listed_modules = self._api.registry_modules.list_all()["data"]
+        self.assertEqual(len(all_listed_modules), 1)
 
         # Search for the module by name, confirm we got it back in the results.
-        search_modules_resp = self._api.registry_modules.search(published_module_name)
-        search_modules = search_modules_resp["modules"]
-        found_module = False
-        for module in search_modules:
-            if module["name"] == published_module_name:
-                found_module = True
-                break
+        _, found_module = self._search_published_module_timeout(published_module_name)
         self.assertTrue(found_module)
 
         # List the module versions, confirm that we got an expected response.
         listed_versions_resp = \
             self._api.registry_modules.list_versions(\
                 published_module_name, TFE_MODULE_PROVIDER_TYPE)
+
         self.assertIn("modules", listed_versions_resp)
-        latest_listed_version = listed_modules[-1]["version"]
+        latest_listed_version = listed_versions_resp["modules"][-1]["versions"][0]["version"]
 
         # List the latest version for all providers, compare to the
         # published module version
@@ -118,7 +101,8 @@ class TestTFCRegistryModules(TestTFCBaseTestCase):
                 published_module_name, TFE_MODULE_PROVIDER_TYPE)
         latest_specific_provider = listed_latest_version_specific_provider["modules"][0]
         latest_specific_versions = \
-            [provider_version["version"] for provider_version in latest_specific_provider["versions"]]
+            [provider_version["version"] for \
+                provider_version in latest_specific_provider["versions"]]
         self.assertIn(latest_listed_version, latest_specific_versions)
 
         # Download the source for a specific version of the module, confirm the file
