@@ -6,6 +6,7 @@ import time
 
 from terrasnek.exceptions import TFCHTTPConflict
 from .base import TestTFCBaseTestCase
+from ._constants import PAGE_START, PAGE_SIZE
 
 
 class TestTFCRuns(TestTFCBaseTestCase):
@@ -68,7 +69,11 @@ class TestTFCRuns(TestTFCBaseTestCase):
             KeyError, lambda: created_run["attributes"]["status-timestamps"]["applying-at"])
 
         # List the runs, using the correct parameters, confirm it has been created
-        some_runs = self._api.runs.list(self._ws_id, page=0, page_size=50)["data"]
+        # and we have our includes.
+        some_runs_raw = self._api.runs.list(self._ws_id, page=PAGE_START, page_size=PAGE_SIZE, include=["plan"])
+        self.assertIn("included", some_runs_raw)
+
+        some_runs = some_runs_raw["data"]
         found_run = False
         for run in some_runs:
             if run["id"] == run_id:
@@ -76,9 +81,11 @@ class TestTFCRuns(TestTFCBaseTestCase):
                 break
         self.assertTrue(found_run)
 
-        all_runs = self._api.runs.list_all(self._ws_id)
+        all_runs = self._api.runs.list_all(self._ws_id, include=["plan"])
+        self.assertIn("included", all_runs)
+
         found_run = False
-        for run in all_runs:
+        for run in all_runs["data"]:
             if run["id"] == run_id:
                 found_run = True
                 break
