@@ -2,7 +2,10 @@
 Module for testing the Terraform Cloud API Endpoint: State Version Outputs.
 """
 
+import time
+
 from .base import TestTFCBaseTestCase
+from ._constants import PAGE_START, PAGE_SIZE
 
 
 class TestTFCStateVersionOutputs(TestTFCBaseTestCase):
@@ -46,7 +49,7 @@ class TestTFCStateVersionOutputs(TestTFCBaseTestCase):
 
         # Create a sample state version
         self._api.workspaces.lock(self._ws_id, {"reason": "Unit testing."})
-        self._api.state_versions.create(self._ws_id, self._get_state_version_create_payload())
+        _ = self._api.state_versions.create(self._ws_id, self._get_state_version_create_payload())["data"]
         self._api.workspaces.unlock(self._ws_id)
 
         # Get the state version ID, using list instead of extracting from the create
@@ -62,16 +65,24 @@ class TestTFCStateVersionOutputs(TestTFCBaseTestCase):
             }
         ]
         state_versions = self._api.state_versions.list(\
-            filters=test_filters, page=0, page_size=50)["data"]
+            filters=test_filters, page=PAGE_START, page_size=PAGE_SIZE)["data"]
         state_version = state_versions[0]
         sv_id = state_version["id"]
 
+        listed_state_version_outputs = self._api.state_version_outputs.list(sv_id, \
+            page=PAGE_START, page_size=PAGE_SIZE)["data"]
+        self.assertEqual(listed_state_version_outputs[0]["type"], "state-version-outputs")
+
         # Get the state version outputs ID, get the outputs, confirm they match the expected IDs
         shown_state_version = self._api.state_versions.show(sv_id)["data"]
         state_version_outputs = shown_state_version["relationships"]["outputs"]["data"]
 
+        time.sleep(3)
         state_version_output_id = state_version_outputs[0]["id"]
         shown_state_version_output = self._api.state_version_outputs.show(
             state_version_output_id)["data"]
         self.assertEqual(state_version_output_id,
                          shown_state_version_output["id"])
+
+        current_state_version_outputs = self._api.state_version_outputs.show_current_for_workspace(self._ws_id)["data"]
+        self.assertEqual(current_state_version_outputs[0]["id"], state_version_output_id)
